/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) Scilab Enterprises - 2014 - Cedric DELAMARRE
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

#include "config_gpu.h"
#ifdef WITH_Nvidia
#pragma OPENCL EXTENSION cl_khr_fp64: enable
#endif

__kernel void dotmult_kernel(__global double* dA, __global double* dB, int elems, __global double* result)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < elems)
    {
        result[posInGrid] = dA[posInGrid] * dB[posInGrid];
    }
}

__kernel void dotmultZ_kernel(__global double2* dA, __global double2* dB, int elems, __global double2* result)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < elems)
    {
        result[posInGrid].x = dA[posInGrid].x * dB[posInGrid].x - dA[posInGrid].y * dB[posInGrid].y;
        result[posInGrid].y = dA[posInGrid].x * dB[posInGrid].y + dA[posInGrid].y * dB[posInGrid].x;
    }
}

__kernel void dotmultZD_kernel(__global double2* dA, __global  double* dB, int elems, __global double2* result)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < elems)
    {
        result[posInGrid].x = dA[posInGrid].x * dB[posInGrid];
        result[posInGrid].y = dA[posInGrid].y * dB[posInGrid];
    }
}
