/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) Scilab Enterprises - 2014 - Cedric DELAMARRE
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

#include "config_gpu.h"
#ifdef WITH_Nvidia
#pragma OPENCL EXTENSION cl_khr_fp64: enable
#endif

__kernel void extract_kernel(__global double* d_inputA, int inputSize, __global double* d_output, __global double* pdblPos, int outputSize)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < outputSize)
    {
        int extractPos = (int)pdblPos[posInGrid];
        if(extractPos <= 0 || extractPos > inputSize)
        {
            return;
        }

        d_output[posInGrid] = d_inputA[extractPos - 1];
    }
}

__kernel void extractZ_kernel(__global double2* d_inputA, int inputSize, __global double2* d_output, __global double* pdblPos, int outputSize)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < outputSize)
    {
        int extractPos = (int)pdblPos[posInGrid];
        if(extractPos <= 0 || extractPos > inputSize)
        {
            return;
        }

        d_output[posInGrid].x = d_inputA[extractPos - 1].x;
        d_output[posInGrid].y = d_inputA[extractPos - 1].y;
    }
}
