/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) Scilab Enterprises - 2014 - Cedric DELAMARRE
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

#include "config_gpu.h"
#ifdef WITH_Nvidia
#pragma OPENCL EXTENSION cl_khr_fp64: enable
#endif

__kernel void insert_kernel(__global double* d_inputA, int inputSize, __global double* d_data, __global double* pdblPos, int dataSize, int isScalar)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < dataSize)
    {
        int insertPos = (int)pdblPos[posInGrid];
        if(insertPos <= 0 || insertPos > inputSize)
        {
            return;
        }

        if(isScalar)
        {
            d_inputA[insertPos - 1] = d_data[0];
        }
        else
        {
            d_inputA[insertPos - 1] = d_data[posInGrid];
        }
    }
}

__kernel void insertZ_kernel(__global double2* d_inputA, int inputSize, __global double2* d_data, __global double* pdblPos, int dataSize, int isScalar)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < dataSize)
    {
        int insertPos = (int)pdblPos[posInGrid];
        if(insertPos <= 0 || insertPos > inputSize)
        {
            return;
        }

        if(isScalar)
        {
            d_inputA[insertPos - 1].x = d_data[0].x;
            d_inputA[insertPos - 1].y = d_data[0].y;
        }
        else
        {
            d_inputA[insertPos - 1].x = d_data[posInGrid].x;
            d_inputA[insertPos - 1].y = d_data[posInGrid].y;
        }
    }
}

__kernel void insertZD_kernel(__global double2* d_inputA, int inputSize, __global double* d_data, __global double* pdblPos, int dataSize, int isScalar)
{
    int posInGrid = get_global_id(0);
    if(posInGrid < dataSize)
    {
        int insertPos = (int)pdblPos[posInGrid];
        if(insertPos <= 0 || insertPos > inputSize)
        {
            return;
        }

        if(isScalar)
        {
            d_inputA[insertPos - 1].x = d_data[0];
            d_inputA[insertPos - 1].y = 0;
        }
        else
        {
            d_inputA[insertPos - 1].x = d_data[posInGrid];
            d_inputA[insertPos - 1].y = 0;
        }
    }
}
